@@ -1,28 +1,49 @@
+pub trait Table {
+    fn table_name() -> &'static str;
+    fn table_name_snake() -> String;
+    fn table_columns() -> &'static [&'static str];
+}
 
 /// Scan trait must be impl macro
-pub trait Scan<Table>{
+pub trait Scan<Table> {
     fn scan(&mut self) -> crate::Result<Table>;
 }
 
 /// Scan trait must be impl macro
-pub trait Scans<Table>{
+pub trait Scans<Table> {
     fn scan(&mut self) -> crate::Result<Vec<Table>>;
 }
 
 /// impl scan for table struct
 /// for example:
 /// ```rust
-/// use cdbc::{impl_scan};
+/// use cdbc::{impl_scan,query};
+/// use cdbc::scan::{Scan,Scans};
 /// pub struct BizActivity {
 ///     pub id: Option<String>,
 ///     pub name: Option<String>,
 ///     pub delete_flag: Option<i32>,
 /// }
 /// impl_scan!(SqliteRow,BizActivity{id:None,name:None,delete_flag:None});
+///
+///
+///  let v:Vec<BizActivity > = query!("select * from biz_activity limit 1").fetch_all(pool)?.scan()?;
 /// ```
 #[macro_export]
 macro_rules! impl_scan {
     ($db_row:path,$table:path{$($field_name:ident: $field_value:expr$(,)?)+}) => {
+    impl $crate::scan::Table for $table{
+    fn table_name() -> &'static str {
+        stringify!($table)
+    }
+    fn table_name_snake() -> String {
+        $crate::to_snake_name(stringify!($table))
+    }
+    fn table_columns() -> &'static [&'static str] {
+        &[$(stringify!($field_name),)+]
+     }
+   }
+
     impl $crate::scan::Scan<$table> for $db_row{
       fn scan(&mut self) -> cdbc::Result<$table> {
           $crate::row_scan!(self,$table { $($field_name:$field_value,)+})
